Module interop

Module interop 

Interop-only schema metadata.

These types describe non-native wire representations used when bridging Eure with external ecosystems (JSON/Serde/codegen).

Structs

UnionInterop
Interop metadata attached to union schemas.

Enums

VariantRepr
How to represent union variants on an external wire format.