pub struct VariantHint {
pub prefix_len: usize,
pub variant: VariantPath,
}Expand description
Explicit variant selection for a union located at a path prefix.
Fields
prefix_len: usizeNumber of path segments consumed when the union is reached.
variant: VariantPathVariant path (possibly nested, e.g. ok.some.left).