LoadedSchemaSet

Struct LoadedSchemaSet 

pub struct LoadedSchemaSet {
    pub root_uri: ResolvedSchemaUri,
    pub documents: IndexMap<ResolvedSchemaUri, EureDocument>,
    pub imports: IndexMap<ResolvedSchemaUri, IndexMap<Identifier, ResolvedSchemaUri>>,
}
A complete set of schema documents that has already been loaded by the caller. Import edges are keyed by the importing document URI and alias.

Fields

root_uri: ResolvedSchemaUridocuments: IndexMap<ResolvedSchemaUri, EureDocument>imports: IndexMap<ResolvedSchemaUri, IndexMap<Identifier, ResolvedSchemaUri>>

Implementations

Source

impl LoadedSchemaSet

pub fn new(root_uri: ResolvedSchemaUri, root_doc: EureDocument) -> Self

pub fn insert_document(&mut self, uri: ResolvedSchemaUri, doc: EureDocument)

pub fn insert_import( &mut self, base: ResolvedSchemaUri, alias: Identifier, target: ResolvedSchemaUri, )

pub fn document(&self, uri: &ResolvedSchemaUri) -> Option<&EureDocument>

pub fn import_target( &self, base: &ResolvedSchemaUri, alias: &Identifier, ) -> Option<&ResolvedSchemaUri>