pub struct SchemaRef {
pub path: String,
pub node_id: NodeId,
}Expand description
Reference to a schema file from $schema extension.
This type is used to extract the schema path from a document’s root node.
The $schema extension specifies the path to the schema file that should
be used to validate the document.
Example
$schema = "./person.schema.eure"
name = "John"
age = 30Fields
path: StringPath to the schema file
node_id: NodeIdNodeId where the $schema was defined (for error reporting)