ValidationError

Enum ValidationError 

pub enum ValidationError {
Show 23 variants TypeMismatch { expected: String, actual: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, MissingRequiredField { field: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, UnknownField { field: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, OutOfRange { value: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, StringLengthOutOfBounds { length: usize, min: Option<u32>, max: Option<u32>, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, PatternMismatch { pattern: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, ArrayLengthOutOfBounds { length: usize, min: Option<u32>, max: Option<u32>, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, MapSizeOutOfBounds { size: usize, min: Option<u32>, max: Option<u32>, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, TupleLengthMismatch { expected: usize, actual: usize, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, ArrayNotUnique { path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, ArrayMissingContains { path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, NoVariantMatched { path: EurePath, best_match: Option<Box<BestVariantMatch>>, node_id: NodeId, schema_node_id: SchemaNodeId, }, AmbiguousUnion { path: EurePath, variants: Vec<String>, node_id: NodeId, schema_node_id: SchemaNodeId, }, InvalidVariantTag { tag: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, ConflictingVariantTags { explicit: String, repr: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, RequiresExplicitVariant { variant: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, LiteralMismatch { expected: String, actual: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, LanguageMismatch { expected: String, actual: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, InvalidKeyType { key: ObjectKey, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, NotMultipleOf { divisor: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, UndefinedTypeReference { name: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, MissingRequiredExtension { extension: String, path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, }, ParseError { path: EurePath, node_id: NodeId, schema_node_id: SchemaNodeId, error: ParseError, },
}
Type errors accumulated during validation.

These represent mismatches between the document and schema. Validation continues after recording these errors.

Variants



TypeMismatch

Fields

expected: String
actual: String
node_id: NodeId
schema_node_id: SchemaNodeId


MissingRequiredField

Fields

field: String
node_id: NodeId
schema_node_id: SchemaNodeId


UnknownField

Fields

field: String
node_id: NodeId
schema_node_id: SchemaNodeId


OutOfRange

Fields

value: String
node_id: NodeId
schema_node_id: SchemaNodeId


StringLengthOutOfBounds

Fields

length: usize
node_id: NodeId
schema_node_id: SchemaNodeId


PatternMismatch

Fields

pattern: String
node_id: NodeId
schema_node_id: SchemaNodeId


ArrayLengthOutOfBounds

Fields

length: usize
node_id: NodeId
schema_node_id: SchemaNodeId


MapSizeOutOfBounds

Fields

size: usize
node_id: NodeId
schema_node_id: SchemaNodeId


TupleLengthMismatch

Fields

expected: usize
actual: usize
node_id: NodeId
schema_node_id: SchemaNodeId


ArrayNotUnique

Fields

node_id: NodeId
schema_node_id: SchemaNodeId


ArrayMissingContains

Fields

node_id: NodeId
schema_node_id: SchemaNodeId


NoVariantMatched

No variant matched in an untagged union validation.

This error occurs when all variants of a union are tried and none succeeds. When available, best_match provides detailed information about which variant came closest to matching and why it failed.

For tagged unions (with $variant or VariantRepr), validation errors are reported directly instead of wrapping them in NoVariantMatched.

Fields

best_match: Option<Box<BestVariantMatch>>

Best matching variant (None if no variants were tried)

node_id: NodeId
schema_node_id: SchemaNodeId


AmbiguousUnion

Fields

variants: Vec<String>
node_id: NodeId
schema_node_id: SchemaNodeId


InvalidVariantTag

Fields

node_id: NodeId
schema_node_id: SchemaNodeId


ConflictingVariantTags

Fields

explicit: String
repr: String
node_id: NodeId
schema_node_id: SchemaNodeId


RequiresExplicitVariant

Fields

variant: String
node_id: NodeId
schema_node_id: SchemaNodeId


LiteralMismatch

Fields

expected: String
actual: String
node_id: NodeId
schema_node_id: SchemaNodeId


LanguageMismatch

Fields

expected: String
actual: String
node_id: NodeId
schema_node_id: SchemaNodeId


InvalidKeyType

Fields

key: ObjectKey

The key that has the wrong type

node_id: NodeId
schema_node_id: SchemaNodeId


NotMultipleOf

Fields

divisor: String
node_id: NodeId
schema_node_id: SchemaNodeId


UndefinedTypeReference

Fields

name: String
node_id: NodeId
schema_node_id: SchemaNodeId


MissingRequiredExtension

Fields

extension: String
node_id: NodeId
schema_node_id: SchemaNodeId


ParseError

Parse error with schema context. Uses custom display to translate ParseErrorKind to user-friendly messages.

Fields

node_id: NodeId
schema_node_id: SchemaNodeId

Implementations

Source

impl ValidationError

pub fn node_ids(&self) -> (NodeId, SchemaNodeId)

Get the node IDs associated with this error.

pub fn depth(&self) -> usize

Calculate the depth of this error (path length).

Deeper errors indicate that validation got further into the structure before failing, suggesting a better match.

pub fn priority_score(&self) -> u8

Get priority score for error type (higher = more indicative of mismatch).

Used for selecting the “best” variant error when multiple variants fail with similar depth and error counts.